==> pkgdepends_0.7.0.tar.gz: pkgdepends/tests/testthat/_snaps/pillar-1.8.1/type-bioc.md <==
# failed resolution

    Code
      as.list(res)
    Output
      $ref
      [1] "bioc::nosuchpackageinbiocforsure"
      
      $type
      [1] "bioc"
      
      $direct
      [1] TRUE
      
      $directpkg
      [1] FALSE
      
      $status
      [1] "FAILED"
      
      $package
      [1] "nosuchpackageinbiocforsure"
      
      $version
      [1] NA
      
      $license
      [1] NA
      
      $needscompilation
      [1] TRUE
      
      $priority
      [1] NA
      
      $md5sum
      [1] NA
      
      $sha256
      [1] NA
      
      $filesize
      [1] NA
      
      $built
      [1] NA
      
      $platform
      [1] "source"
      
      $rversion
      [1] "*"
      
      $repotype
      [1] NA
      
      $repodir
      [1] "src/contrib"
      
      $target
      [1] "src/contrib/nosuchpackageinbiocforsure_NA.tar.gz"
      
      $deps
      $deps[[1]]
      # A data frame: 0 x 5
      # ... with 5 variables: ref <chr>, type <chr>, package <chr>, op <chr>,
      #   version <chr>
      
      
      $mirror
      [1] NA
      
      $sources
      $sources[[1]]
      [1] NA
      
      
      $remote
      $remote[[1]]
      $package
      [1] "nosuchpackageinbiocforsure"
      
      $atleast
      [1] ""
      
      $version
      [1] ""
      
      $ref
      [1] "bioc::nosuchpackageinbiocforsure"
      
      $type
      [1] "bioc"
      
      $params
      character(0)
      
      attr(,"class")
      [1] "remote_ref_bioc" "remote_ref"      "list"           
      
      
      $error
      $error[[1]]
      <error: Can't find package called bioc::nosuchpackageinbiocforsure.>
      
      
      $metadata
      $metadata[[1]]
      list()
      
      
      $extra
      $extra[[1]]
      list()
      
      
      $params
      $params[[1]]
      character(0)
      
      
      $sysreqs
      [1] NA

==> pkgdepends_0.9.0.tar.gz: pkgdepends/tests/testthat/_snaps/pillar-1.9.0/type-bioc.md <==
# failed resolution

    Code
      as.list(res)
    Output
      $ref
      [1] "bioc::nosuchpackageinbiocforsure"
      
      $type
      [1] "bioc"
      
      $direct
      [1] TRUE
      
      $directpkg
      [1] FALSE
      
      $status
      [1] "FAILED"
      
      $package
      [1] "nosuchpackageinbiocforsure"
      
      $version
      [1] NA
      
      $license
      [1] NA
      
      $needscompilation
      [1] TRUE
      
      $priority
      [1] NA
      
      $md5sum
      [1] NA
      
      $sha256
      [1] NA
      
      $filesize
      [1] NA
      
      $built
      [1] NA
      
      $platform
      [1] "source"
      
      $rversion
      [1] "*"
      
      $repotype
      [1] NA
      
      $repodir
      [1] "src/contrib"
      
      $target
      [1] "src/contrib/nosuchpackageinbiocforsure_NA.tar.gz"
      
      $deps
      $deps[[1]]
      # A data frame: 0 x 5
      # i 5 variables: ref <chr>, type <chr>, package <chr>, op <chr>, version <chr>
      
      
      $mirror
      [1] NA
      
      $sources
      $sources[[1]]
      [1] NA
      
      
      $remote
      $remote[[1]]
      $package
      [1] "nosuchpackageinbiocforsure"
      
      $atleast
      [1] ""
      
      $version
      [1] ""
      
      $ref
      [1] "bioc::nosuchpackageinbiocforsure"
      
      $type
      [1] "bioc"
      
      $params
      character(0)
      
      attr(,"class")
      [1] "remote_ref_bioc" "remote_ref"      "list"           
      
      
      $error
      $error[[1]]
      <error: Can't find package called bioc::nosuchpackageinbiocforsure.>
      
      
      $metadata
      $metadata[[1]]
      list()
      
      
      $extra
      $extra[[1]]
      list()
      
      
      $params
      $params[[1]]
      character(0)
      
      
      $sysreqs
      [1] NA
      
      $os_type
      [1] NA
